@@ -17,6 +17,10 @@ import os
 import sys
 
 
+if not os.getcwd() == os.path.abspath(os.path.dirname(sys.argv[0])):          #check if we are in the directory where we need to be in order to utilize our relative paths.
+    os.chdir(os.path.dirname(sys.argv[0]))
+
+
 class GUI:
     def __init__(self, master):
         self.master = master
@@ -99,27 +103,28 @@ class Entry_formular:
 
         # label for entry button amino acid substitution
 
-        self.header = tk.Label(self.frame, text="AMIVA-F analysis of mutations in variants of human Filamin C", font="Helvetica 16 bold", fg="black")
-        self.header.grid(row=0, column=0, sticky="nswe", ipady=5)
+        self.header = tk.Label(self.frame, text=" AMIVA-F analysis of mutations in variants of human Filamin C ", font="Helvetica 16 bold", bg="#3B5998", fg="#EDF0F5")
+        self.header.grid(row=0, column=0, sticky="nswe", ipady=5, pady=(15, 5))
         self.label1 = tk.Label(self.frame, text="Please enter your mutation of interest into the entry field below.")
         self.label1.grid(row=1, column=0, columnspan=1, sticky="news")
-        self.label2 = tk.Label(self.frame, text="Accepted format: e.g M82K", font="Helvetica 10 bold")
+        self.label2 = tk.Label(self.frame, text="Accepted format: e.g M82K", font="Helvetica 12 bold")
         self.label2.grid(row=2, column=0, ipadx=10, sticky="news")
         self.label3 = tk.Label(self.frame, text="for Methionine (M) being mutated to Lysine (K) ")
         self.label3.grid(row=3, column=0, ipadx=10, sticky="news")
-        self.label4 = tk.Label(self.frame, text="Allowed range:\n35 - 2725", font="helvetica 10 italic")
+        self.label4 = tk.Label(self.frame, text="Allowed range: 35 - 2725", font="helvetica 10 italic")
         self.label4.grid(row=4, column=0, ipadx=10, columnspan=1, sticky="news")
 
         # entry + button for amino acid substitution
-        self.entry1 = tk.Entry(self.frame)
-        self.entry1.grid(row=5, column=0)
+        self.entry1 = tk.Entry(self.frame, font="helvetica 14", width=8)
+        self.entry1.grid(row=5, column=0, ipady=5)
         self.lblexplain = tk.Label(self.frame, text="After entering your desired mutation"
                                                     ", the blue button will give you a prediction after a couple of seconds")
+
         self.lblexplain.grid(row=6, column=0)
-        self.button = tk.Button(self.frame, text="Predict mutation!"
-                                , relief="ridge", borderwidth=4, bg="blue", fg="white",height=2, width=15,
+        self.button = tk.Button(self.frame, text="AMIVA-F Analysis"
+                                , borderwidth=3, bg="#3B5998", fg="#EDF0F5", height=2, width=15, highlightthickness=0,
                                 command=lambda:[self.hydrophobicity_atomnumb(), entry_form.outfile_handler_weka()])
-        self.button.config(font="helvetica 10 bold")
+        self.button.config(font="helvetica 15 bold")
         self.button.grid(row=7, column=0, pady=(10,10))
 
         self.phosphohits = []
@@ -150,8 +155,7 @@ class Entry_formular:
 
         """Clear all entries before run/ so that prior runs don't get overwritten"""
 
-        self.pb["value"] += 20
-        self.pb.update_idletasks()
+
         for entries in entryids:
             entries.delete(0,"end")
         entry_form.var.set(1)
@@ -169,8 +173,10 @@ class Entry_formular:
         global entry_start
         entry_start = self.entry1.get()
         mutation_ids.append(entry_start)
-        aa_wt = entry_start[0:1]
-        aa_mut = entry_start[-1:]
+        aa_wt = entry_start[0:1].upper()
+        aa_mut = entry_start[-1:].upper()
+        self.entry1.delete(0,"end")
+        self.entry1.insert(0, entry_start.upper())
         global pos
         pos = entry_start[1:-1]
 
@@ -313,6 +319,8 @@ class Entry_formular:
                     messagebox.showerror("Wrong amino acid!","Cant proceed with wrong amino acid! \nLeaving the application now")
                     root.after(2000, root.destroy())
 
+            self.pb["value"] += 20
+            self.pb.update_idletasks()
 
             #structure = freesasa.Structure(pdbfile1_0, {"hetatm": False, "hydrogen": False})
             #print(structure[0]["A"][int(pos)])
@@ -1195,7 +1203,6 @@ class Entryfield:
         self.wekaentrydomaininfo.delete(0, tk.END)
         self.wekaentrydis.delete(0, tk.END)
         entry_form.clear_btn()
-        intro_form.button.config(bg="blue")
         intro_form.pb["value"] = 0
 
     def wekaprediction(self):
@@ -1281,7 +1288,6 @@ class Entryfield:
                 self.wekaentryid.config(font="Helvetica 18")
                 self.wekaentrydomaininfo.insert(0, domaininfo)
                 self.wekaentrydomaininfo.config(font="Helvetica 18")
-                intro_form.button.config(bg="red")
             else:
                 self.wekaentrydis.insert(0, "neutral/benign")
                 #self.wekaentryconf.insert(0, round(values,2))
@@ -1291,7 +1297,7 @@ class Entryfield:
                 self.wekaentryid.config(font="Helvetica 18")
                 self.wekaentrydomaininfo.insert(0,domaininfo)
                 self.wekaentrydomaininfo.config(font="Helvetica 18")
-                intro_form.button.config(bg="green")
+
 
         if falsepredict == True:     #with wrong inputs we just clear random stuff that make no sense.
             self.clearweka()
